@@ -1,15 +1,9 @@
 $LOAD_PATH.unshift(File.dirname(__FILE__))
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
 require 'text-table'
-require 'spec'
-require 'spec/autorun'
+require 'rspec'
+require 'rspec/autorun'
 
-Spec::Runner.configure do |config|
-  
-end
-
-class String
-  def deindent
-    gsub /^[ \t]*/, ''
-  end
+def deindent(table)
+  table.gsub(/^\s*/, '')
 end
